@@ -26,17 +26,21 @@ sub parse_line {  #  See: https://adblockplus.org/en/filters
     return {} if /#\@#/;
 
     return {} if /##/;
-    
+
+    return {} if /\$.*domain=/;
 
     
     if (/^\|\|($domchars)\^(\$|$)/) {
-        return { d => $1 };
+        my $domain = $1;
+        # Output domain here for debugging purposes.
+        return { d => $domain };
     }
     
     return {} if /\$/;
 
     
     return {} if m,^\|http://,;
+    
 
     if (/^\|\|/) {
         s/^\|\|//;
